@@ -1,7 +1,10 @@
+#include "analyzer/analyzergain.h"
+
 #include <replaygain.h>
+
 #include <QtDebug>
 
-#include "analyzer/analyzergain.h"
+#include "analyzer/constants.h"
 #include "track/track.h"
 #include "util/math.h"
 #include "util/sample.h"
@@ -11,7 +14,7 @@ AnalyzerGain::AnalyzerGain(UserSettingsPointer pConfig)
         : m_rgSettings(pConfig),
           m_pLeftTempBuffer(nullptr),
           m_pRightTempBuffer(nullptr),
-          m_iBufferSize(0) {
+          m_bufferSize(0) {
     m_pReplayGain = new ReplayGain();
 }
 
@@ -21,36 +24,40 @@ AnalyzerGain::~AnalyzerGain() {
     delete m_pReplayGain;
 }
 
-bool AnalyzerGain::initialize(TrackPointer tio, int sampleRate, int totalSamples) {
-    if (m_rgSettings.isAnalyzerDisabled(1, tio) || totalSamples == 0) {
+bool AnalyzerGain::initialize(TrackPointer pTrack,
+        mixxx::audio::SampleRate sampleRate,
+        SINT frameLength) {
+    if (m_rgSettings.isAnalyzerDisabled(1, pTrack) || frameLength <= 0) {
         qDebug() << "Skipping AnalyzerGain";
         return false;
     }
 
-    return m_pReplayGain->initialise((long)sampleRate, 2);
+    return m_pReplayGain->initialise(
+            sampleRate,
+            mixxx::kAnalysisChannels);
 }
 
 void AnalyzerGain::cleanup() {
 }
 
-bool AnalyzerGain::processSamples(const CSAMPLE *pIn, const int iLen) {
+bool AnalyzerGain::processSamples(const CSAMPLE* pIn, SINT count) {
     ScopedTimer t("AnalyzerGain::process()");
 
-    int halfLength = static_cast<int>(iLen / 2);
-    if (halfLength > m_iBufferSize) {
+    SINT numFrames = count / mixxx::kAnalysisChannels;
+    if (numFrames > m_bufferSize) {
         delete[] m_pLeftTempBuffer;
         delete[] m_pRightTempBuffer;
-        m_pLeftTempBuffer = new CSAMPLE[halfLength];
-        m_pRightTempBuffer = new CSAMPLE[halfLength];
-        m_iBufferSize = halfLength;
+        m_pLeftTempBuffer = new CSAMPLE[numFrames];
+        m_pRightTempBuffer = new CSAMPLE[numFrames];
+        m_bufferSize = numFrames;
     }
-    SampleUtil::deinterleaveBuffer(m_pLeftTempBuffer, m_pRightTempBuffer, pIn, halfLength);
-    SampleUtil::applyGain(m_pLeftTempBuffer, 32767, halfLength);
-    SampleUtil::applyGain(m_pRightTempBuffer, 32767, halfLength);
-    return m_pReplayGain->process(m_pLeftTempBuffer, m_pRightTempBuffer, halfLength);
+    SampleUtil::deinterleaveBuffer(m_pLeftTempBuffer, m_pRightTempBuffer, pIn, numFrames);
+    SampleUtil::applyGain(m_pLeftTempBuffer, 32767, numFrames);
+    SampleUtil::applyGain(m_pRightTempBuffer, 32767, numFrames);
+    return m_pReplayGain->process(m_pLeftTempBuffer, m_pRightTempBuffer, numFrames);
 }
 
-void AnalyzerGain::storeResults(TrackPointer tio) {
+void AnalyzerGain::storeResults(TrackPointer pTrack) {
     //TODO: We are going to store values as relative peaks so that "0" means that no replaygain has been evaluated.
     // This means that we are going to transform from dB to peaks and vice-versa.
     // One may think to digg into replay_gain code and modify it so that
@@ -63,8 +70,9 @@ void AnalyzerGain::storeResults(TrackPointer tio) {
         return;
     }
 
-    mixxx::ReplayGain replayGain(tio->getReplayGain());
+    mixxx::ReplayGain replayGain(pTrack->getReplayGain());
     replayGain.setRatio(db2ratio(fReplayGainOutput));
-    tio->setReplayGain(replayGain);
-    qDebug() << "ReplayGain 1.0 result is" << fReplayGainOutput << "dB for" << tio->getLocation();
+    pTrack->setReplayGain(replayGain);
+    qDebug() << "ReplayGain 1.0 result is" << fReplayGainOutput << "dB for"
+             << pTrack->getLocation();
 }
