@@ -16,20 +16,26 @@ using namespace soundtouch;
 
 namespace {
 
-// Due to filtering and oversampling, SoundTouch is some samples behind.
-// The value below was experimental identified using a saw signal and SoundTouch 1.8
-// at a speed of 1.0
-// 0.918 (upscaling 44.1 kHz to 48 kHz) will produce an additional offset of 3 Frames
-// 0.459 (upscaling 44.1 kHz to 96 kHz) will produce an additional offset of 18 Frames
-// (Rubberband does not suffer this issue)
-const SINT kSeekOffsetFrames = 519;
+// Due to filtering and oversampling, SoundTouch is some samples behind (offset).
+// The value below was experimental identified using a saw signal and SoundTouch 2.1.1
+constexpr SINT kSeekOffsetFramesV20101 = 429;
+
+// From V 2.3.0 Soundtouch has no initial offset at unity, but it is too late with
+// lowered pitch and too early with raised pitch up to ~+-2000 frames (~+-50 ms).
+// This can be seen in a recording of a saw signal with changed pitch.
+// The saws tooth are shifted from their input position depending on the pitch.
+// TODO() Compensate that. This is probably cause by the delayed adoption of pitch changes due
+// to the SoundTouch chunk size.
+
+constexpr SINT kBackBufferSize = 1024;
 
 }  // namespace
 
-EngineBufferScaleST::EngineBufferScaleST(ReadAheadManager *pReadAheadManager)
-    : m_pReadAheadManager(pReadAheadManager),
-      m_pSoundTouch(std::make_unique<soundtouch::SoundTouch>()),
-      m_bBackwards(false) {
+EngineBufferScaleST::EngineBufferScaleST(ReadAheadManager* pReadAheadManager)
+        : m_pReadAheadManager(pReadAheadManager),
+          m_pSoundTouch(std::make_unique<soundtouch::SoundTouch>()),
+          m_bufferBack(kBackBufferSize),
+          m_bBackwards(false) {
     m_pSoundTouch->setChannels(getOutputSignal().getChannelCount());
     m_pSoundTouch->setRate(m_dBaseRate);
     m_pSoundTouch->setPitch(1.0);
@@ -37,7 +43,6 @@ EngineBufferScaleST::EngineBufferScaleST(ReadAheadManager *pReadAheadManager)
     // Initialize the internal buffers to prevent re-allocations
     // in the real-time thread.
     onSampleRateChanged();
-
 }
 
 EngineBufferScaleST::~EngineBufferScaleST() {
@@ -90,31 +95,31 @@ void EngineBufferScaleST::setScaleParameters(double base_rate,
 }
 
 void EngineBufferScaleST::onSampleRateChanged() {
-    buffer_back.clear();
+    m_bufferBack.clear();
     if (!getOutputSignal().isValid()) {
         return;
     }
     m_pSoundTouch->setSampleRate(getOutputSignal().getSampleRate());
-    const auto bufferSize = getOutputSignal().frames2samples(kSeekOffsetFrames);
-    if (bufferSize > buffer_back.size()) {
-        // grow buffer
-        buffer_back = mixxx::SampleBuffer(bufferSize);
-    }
+
     // Setting the tempo to a very low value will force SoundTouch
     // to preallocate buffers large enough to (almost certainly)
     // avoid memory reallocations during playback.
     m_pSoundTouch->setTempo(0.1);
-    m_pSoundTouch->putSamples(buffer_back.data(), kSeekOffsetFrames);
-    m_pSoundTouch->clear();
     m_pSoundTouch->setTempo(m_dTempoRatio);
+    clear();
 }
 
 void EngineBufferScaleST::clear() {
     m_pSoundTouch->clear();
 
     // compensate seek offset for a rate of 1.0
-    SampleUtil::clear(buffer_back.data(), buffer_back.size());
-    m_pSoundTouch->putSamples(buffer_back.data(), kSeekOffsetFrames);
+    if (SoundTouch::getVersionId() < 20302) {
+        DEBUG_ASSERT(SoundTouch::getVersionId() >= 20101);
+        // from SoundTouch 2.3.0 the initial offset is corrected internally
+        m_effectiveRate = m_dBaseRate * m_dTempoRatio;
+        SampleUtil::clear(m_bufferBack.data(), m_bufferBack.size());
+        m_pSoundTouch->putSamples(m_bufferBack.data(), kSeekOffsetFramesV20101);
+    }
 }
 
 double EngineBufferScaleST::scaleBuffer(
@@ -127,8 +132,7 @@ double EngineBufferScaleST::scaleBuffer(
         return 0.0;
     }
 
-    SINT total_received_frames = 0;
-
+    double readFramesProcessed = 0;
     SINT remaining_frames = getOutputSignal().samples2frames(iOutputBufferSize);
     CSAMPLE* read = pOutputBuffer;
     bool last_read_failed = false;
@@ -137,38 +141,44 @@ double EngineBufferScaleST::scaleBuffer(
                 read, remaining_frames);
         DEBUG_ASSERT(remaining_frames >= received_frames);
         remaining_frames -= received_frames;
-        total_received_frames += received_frames;
+        readFramesProcessed += m_effectiveRate * received_frames;
         read += getOutputSignal().frames2samples(received_frames);
 
         if (remaining_frames > 0) {
+            // The requested setting becomes effective after all previous frames have been processed
+            m_effectiveRate = m_dBaseRate * m_dTempoRatio;
             SINT iAvailSamples = m_pReadAheadManager->getNextSamples(
-                        // The value doesn't matter here. All that matters is we
-                        // are going forward or backward.
-                        (m_bBackwards ? -1.0 : 1.0) * m_dBaseRate * m_dTempoRatio,
-                        buffer_back.data(),
-                        buffer_back.size());
+                    // The value doesn't matter here. All that matters is we
+                    // are going forward or backward.
+                    (m_bBackwards ? -1.0 : 1.0) * m_effectiveRate,
+                    m_bufferBack.data(),
+                    m_bufferBack.size());
             SINT iAvailFrames = getOutputSignal().samples2frames(iAvailSamples);
 
             if (iAvailFrames > 0) {
                 last_read_failed = false;
-                m_pSoundTouch->putSamples(buffer_back.data(), iAvailFrames);
+                m_pSoundTouch->putSamples(m_bufferBack.data(), iAvailFrames);
             } else {
+                // We may get 0 samples once if we just hit a loop trigger, e.g.
+                // when reloop_toggle jumps back to loop_in, or when moving a
+                // loop causes the play position to be moved along.
                 if (last_read_failed) {
-                    m_pSoundTouch->flush();
-                    break; // exit loop after failure
+                    // If we get 0 samples repeatedly, add silence that allows
+                    // to flush the last samples out of Soundtouch.
+                    // m_pSoundTouch->flush() must not be used, because it allocates
+                    // a temporary buffer in the heap which maybe locking
+                    qDebug() << "ReadAheadManager::getNextSamples() returned "
+                                "zero samples repeatedly. Padding with silence.";
+                    SampleUtil::clear(m_bufferBack.data(), m_bufferBack.size());
+                    m_pSoundTouch->putSamples(m_bufferBack.data(), m_bufferBack.size());
                 }
                 last_read_failed = true;
             }
         }
     }
 
-    // framesRead is interpreted as the total number of virtual sample frames
+    // readFramesProcessed is interpreted as the total number of frames
     // consumed to produce the scaled buffer. Due to this, we do not take into
     // account directionality or starting point.
-    // NOTE(rryan): Why no m_dPitchAdjust here? SoundTouch implements pitch
-    // shifting as a tempo shift of (1/m_dPitchAdjust) and a rate shift of
-    // (*m_dPitchAdjust) so these two cancel out.
-    double framesRead = m_dBaseRate * m_dTempoRatio * total_received_frames;
-
-    return framesRead;
+    return readFramesProcessed;
 }
