@@ -182,8 +182,10 @@ class EngineBuffer : public EngineObject {
 
   private slots:
     void slotTrackLoading();
-    void slotTrackLoaded(TrackPointer pTrack,
-                         int iSampleRate, int iNumSamples);
+    void slotTrackLoaded(
+            TrackPointer pTrack,
+            int trackSampleRate,
+            double trackNumSamples);
     void slotTrackLoadFailed(TrackPointer pTrack,
             const QString& reason);
     // Fired when passthrough mode is enabled or disabled.
@@ -329,8 +331,6 @@ class EngineBuffer : public EngineObject {
     ControlPushButton* m_stopStartButton;
     ControlPushButton* m_stopButton;
 
-    ControlObject* m_fwdButton;
-    ControlObject* m_backButton;
     ControlPushButton* m_pSlipButton;
 
     ControlObject* m_pQuantize;
