@@ -609,6 +609,12 @@ bool ShoutConnection::processConnect() {
             kLogger.warning()
                     << "processConnect() socket error."
                     << "Is socket already in use?";
+        } else if (timeout >= kConnectRetries) {
+            // Not translated, because shout_get_error() returns also English only
+            m_lastErrorStr = QStringLiteral("Connection establishment time-out");
+            kLogger.warning()
+                    << "processConnect() error:"
+                    << m_iShoutStatus << m_lastErrorStr;
         } else if (m_pProfile->getEnabled()) {
             m_lastErrorStr = shout_get_error(m_pShout);
             kLogger.warning()
