@@ -26,12 +26,9 @@ class BaseExternalLibraryFeature : public LibraryFeature {
     void onRightClickChild(const QPoint& globalPos, const QModelIndex& index) override;
 
   protected:
-    // Must be implemented by external Libraries copied to Mixxx DB
+    // Must be re-implemented by external Libraries copied to Mixxx DB
     virtual std::unique_ptr<BaseSqlTableModel> createPlaylistModelForPlaylist(
-            const QString& playlist) {
-        Q_UNUSED(playlist);
-        return {};
-    }
+            const QString& playlist);
     // Must be implemented by external Libraries not copied to Mixxx DB
     virtual void appendTrackIdsFromRightClickIndex(QList<TrackId>* trackIds, QString* pPlaylist);
 
