@@ -181,8 +181,10 @@ const QList<int>& BrowseTableModel::searchColumns() const {
 }
 
 void BrowseTableModel::setPath(const MDir& path) {
-    m_current_directory = path;
-    m_pBrowseThread->executePopulation(m_current_directory, this);
+    if (m_pBrowseThread) {
+        m_current_directory = path;
+        m_pBrowseThread->executePopulation(m_current_directory, this);
+    }
 }
 
 TrackPointer BrowseTableModel::getTrack(const QModelIndex& index) const {
@@ -471,3 +473,10 @@ QAbstractItemDelegate* BrowseTableModel::delegateForColumn(const int i, QObject*
     }
     return nullptr;
 }
+
+void BrowseTableModel::releaseBrowseThread() {
+    // The shared browse thread is stopped in the destructor
+    // if this is the last reference. All references must be reset before
+    // the library is destructed.
+    m_pBrowseThread.reset();
+}
