@@ -19,6 +19,7 @@
 #include <QUrl>
 #include <QtDebug>
 
+#include "errordialoghandler.h"
 #include "moc_parserm3u.cpp"
 
 /**
@@ -52,7 +53,8 @@ QList<QString> ParserM3u::parse(const QString& sFilename) {
     if (!file.open(QIODevice::ReadOnly)) {
         qWarning()
                 << "Failed to open playlist file"
-                << sFilename;
+                << sFilename
+                << file.errorString();
         return m_sLocations;
     }
 
@@ -146,9 +148,13 @@ bool ParserM3u::writeM3UFile(const QString &file_str, const QList<QString> &item
 
     QFile file(file_str);
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        QMessageBox::warning(nullptr,
-                tr("Playlist Export Failed"),
-                tr("Could not create file") + " " + file_str);
+        ErrorDialogHandler* pDialogHandler = ErrorDialogHandler::instance();
+        ErrorDialogProperties* props = pDialogHandler->newDialogProperties();
+        props->setType(DLG_WARNING);
+        props->setTitle(tr("Playlist Export Failed"));
+        props->setText(tr("Could not create file") + " " + file_str);
+        props->setDetails(file.errorString());
+        pDialogHandler->requestErrorDialog(props);
         return false;
     }
 
