@@ -63,6 +63,8 @@ class LoopingControlTest : public MockedEngineBackendTest {
         m_pButtonBeatLoopRoll1Activate = std::make_unique<ControlProxy>(m_sGroup1, "beatlooproll_1_activate");
         m_pButtonBeatLoopRoll2Activate = std::make_unique<ControlProxy>(m_sGroup1, "beatlooproll_2_activate");
         m_pButtonBeatLoopRoll4Activate = std::make_unique<ControlProxy>(m_sGroup1, "beatlooproll_4_activate");
+
+        ProcessBuffer();
     }
 
     bool isLoopEnabled() {
@@ -158,6 +160,28 @@ TEST_F(LoopingControlTest, LoopInSetAfterLoopOutStops) {
     EXPECT_EQ(-1, m_pLoopEndPoint->get());
 }
 
+TEST_F(LoopingControlTest, LoopInSetAtLoopOutClearsLoopOut) {
+    m_pLoopStartPoint->slotSet(0);
+    m_pLoopEndPoint->slotSet(100);
+    m_pLoopStartPoint->slotSet(100);
+    EXPECT_EQ(100, m_pLoopStartPoint->get());
+    EXPECT_EQ(-1, m_pLoopEndPoint->get());
+    EXPECT_FALSE(isLoopEnabled());
+}
+
+TEST_F(LoopingControlTest, LoopOutSetAtLoopInIgnored) {
+    m_pLoopStartPoint->slotSet(0);
+    m_pLoopEndPoint->slotSet(100);
+    m_pLoopEndPoint->slotSet(0);
+    EXPECT_EQ(0, m_pLoopStartPoint->get());
+    EXPECT_EQ(100, m_pLoopEndPoint->get());
+    m_pLoopEndPoint->slotSet(-1);
+    EXPECT_EQ(-1, m_pLoopEndPoint->get());
+    m_pLoopEndPoint->slotSet(0);
+    EXPECT_FALSE(isLoopEnabled());
+    EXPECT_EQ(-1, m_pLoopEndPoint->get());
+}
+
 TEST_F(LoopingControlTest, LoopOutSetInsideLoopContinues) {
     m_pLoopStartPoint->slotSet(0);
     m_pLoopEndPoint->slotSet(100);
@@ -427,8 +451,10 @@ TEST_F(LoopingControlTest, LoopDoubleButton_IgnoresPastTrackEnd) {
 TEST_F(LoopingControlTest, LoopDoubleButton_DoublesBeatloopSize) {
     m_pTrack1->trySetBpm(120.0);
     m_pBeatLoopSize->set(16.0);
+    EXPECT_EQ(16.0, m_pBeatLoopSize->get());
     m_pButtonBeatLoopActivate->set(1.0);
     m_pButtonBeatLoopActivate->set(0.0);
+    EXPECT_EQ(16.0, m_pBeatLoopSize->get());
     m_pButtonLoopDouble->set(1.0);
     m_pButtonLoopDouble->set(0.0);
     EXPECT_EQ(32.0, m_pBeatLoopSize->get());
