@@ -6,6 +6,7 @@
 
 #include "proto/keys.pb.h"
 #include "track/keys.h"
+#include "util/types.h"
 
 class KeyFactory {
   public:
@@ -22,10 +23,11 @@ class KeyFactory {
     static QString getPreferredVersion();
 
     static QString getPreferredSubVersion(
-        const QHash<QString, QString>& extraVersionInfo);
+            const QHash<QString, QString>& extraVersionInfo);
 
     static Keys makePreferredKeys(
-        const KeyChangeList& key_changes,
-        const QHash<QString, QString>& extraVersionInfo,
-        const int iSampleRate, const int iTotalSamples);
+            const KeyChangeList& key_changes,
+            const QHash<QString, QString>& extraVersionInfo,
+            int iSampleRate,
+            SINT totalFrames);
 };
