@@ -801,7 +801,7 @@ QByteArray SeratoMarkers2::dumpFLAC() const {
 }
 
 std::optional<SeratoStoredTrackColor> SeratoMarkers2::getTrackColor() const {
-    kLogger.info() << "Reading track color from 'Serato Markers2' tag data...";
+    kLogger.debug() << "Reading track color from 'Serato Markers2' tag data...";
 
     for (const auto& pEntry : qAsConst(m_entries)) {
         VERIFY_OR_DEBUG_ASSERT(pEntry) {
@@ -851,7 +851,7 @@ void SeratoMarkers2::setTrackColor(SeratoStoredTrackColor color) {
 }
 
 bool SeratoMarkers2::isBpmLocked() const {
-    kLogger.info() << "Reading bpmlock state from 'Serato Markers2' tag data...";
+    kLogger.debug() << "Reading bpmlock state from 'Serato Markers2' tag data...";
 
     for (const auto& pEntry : qAsConst(m_entries)) {
         VERIFY_OR_DEBUG_ASSERT(pEntry) {
