@@ -50,7 +50,7 @@ void WaveformRendererFilteredSignal::draw(QPainter* painter,
         return;
     }
 
-    const int trackSamples = m_waveformRenderer->getTrackSamples();
+    const double trackSamples = m_waveformRenderer->getTrackSamples();
     if (trackSamples <= 0) {
         return;
     }
